/*
Description:

Dynamically creates a FlatButton material widget which responds to a press and long press.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-flatButton.dart';

Usage:

The 'child' parameter accepts a widget to be displayed on the button and can be specified to be a Text, Icon, Image,etc.
The parameters such as shape,color,width,height,focusColor,hoverColor,highlightColor,splashColor,etc can be passed using the class 'FlatButtonParameters'.
onPress, & onLongPress callback functions can be passed which returns a 'true' value and can be used to define further actions to be performed on press & on long press respectively.
 A flatButton with default parameters is created when null is passed as FlatButtonParameters.




- Defining the callback and FlatButton objects

onButtonPress(bool b){
      print(b);
    }

    onButtonLongPress(bool b){
      print(b);
    }
    FlatButtonParameters buttonObject = FlatButtonParameters(child:Text('Submit'),color:Colors.pinkAccent,textColor:Colors.white,hoverColor: Colors.grey,width: 150,focusColor: Colors.grey,height: 50,highlightColor: Colors.grey,splashColor: Colors.white);


- Object call for the widget

customFlatButton(buttonObject, onButtonPress, onButtonLongPress),

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart' as con;
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/theme.dart';
import 'custom-text.dart';





Widget customFlatButton(
  FlatButtonParameters param,
  void Function(bool) onPress,
  void Function(bool) onLongPress,
) {
  if (param == null && onPress == null && onLongPress == null) {
    return ButtonTheme(
      minWidth: con.heightHundred,
      height: con.heightTwenty,
      child: FlatButton(
        child: customText(
            TextParameters(
              text: param.text,
              blur_radius:  param.blur_radius,
              textColor:  param.textColor,
              textAlign: param.textAlign,
              spread_radius: param.spread_radius,
              icon1_color: param.icon1_color,
              icon2_color: param.icon2_color,
              icon2: param.icon2,
              icon1: param.icon1,
              icon2_size: param.icon2_size,
              icon1_size:  param.icon1_size,
              fontSize: param.fontSize,
              fontWeight: param.fontWeight,
              height: param.height,
              fontStyle: param.fontStyle,
              border_radius: param.border_radius,
              BorderColor: param.BorderColor,
              boxshadowcolor: param.boxshadowcolor,
              ContainerColor: param.ContainerColor,
              fontFamily: param.fontFamily,
              maxLines: param.maxLines,
              pad_val_all_wrap_icon: param.pad_val_all_wrap_icon,
              pad_val_all_wrap_text: param.pad_val_all_wrap_text,
              pad_val_bottom_wrap_icon: param.pad_val_bottom_wrap_icon,
              pad_val_l_wrap_icon: param.pad_val_l_wrap_icon,
              pad_val_r_wrap_icon: param.pad_val_r_wrap_icon,
              pad_val_top_wrap_icon: param.pad_val_top_wrap_icon,
              pad_val_bottom_wrap_text: param.pad_val_bottom_wrap_text,
              pad_val_l_wrap_text: param.pad_val_l_wrap_text,
              pad_val_r_wrap_text: param.pad_val_r_wrap_text,
              pad_val_top_wrap_text: param.pad_val_top_wrap_text,
              opacity: param.opacity,


        )),
        color: mediumGreyThemeData().buttonColor,
        colorBrightness: mediumGreyThemeData().brightness,
        disabledColor: mediumGreyThemeData().disabledColor,
        disabledTextColor: mediumGreyThemeData().disabledColor,
        focusColor: mediumGreyThemeData().focusColor,
        highlightColor: mediumGreyThemeData().highlightColor,
        hoverColor: mediumGreyThemeData().hoverColor,
        onPressed: () {},
        onLongPress: () {},
        shape: con.outlineButtonShape,
      ),
    );
  } else {
    return ButtonTheme(
      minWidth: param.width != null ? param.width : con.heightHundred,
      height: param.height != null ? param.height : con.heightTwenty,
      child: FlatButton(
        autofocus: param.autofocus != null ? param.autofocus : false,
        child: param.child != null ? param.child : customText(TextParameters(text: con.buttonLabel, textColor: Colors.grey)),
        color: (param.color != null)
            ? param.color
            : mediumGreyThemeData().buttonColor,
        colorBrightness: (param.colorBrightness != null)
            ? param.colorBrightness
            : mediumGreyThemeData().brightness,
        disabledColor: (param.disabledColor != null)
            ? param.disabledColor
            : mediumGreyThemeData().disabledColor,
        disabledTextColor: (param.disabledTextColor != null)
            ? param.disabledTextColor
            : mediumGreyThemeData().disabledColor,
        focusColor: (param.focusColor != null)
            ? param.focusColor
            : mediumGreyThemeData().focusColor,
        highlightColor: (param.highlightColor != null)
            ? param.highlightColor
            : mediumGreyThemeData().highlightColor,
        hoverColor: (param.hoverColor != null)
            ? param.hoverColor
            : mediumGreyThemeData().hoverColor,
        splashColor: (param.splashColor != null)
            ? param.splashColor
            : mediumGreyThemeData().splashColor,
        shape: (param.shape != null) ? param.shape : con.outlineButtonShape,
        textColor: (param.textColor != null)
            ? param.textColor
            : mediumGreyThemeData().textSelectionColor,
        focusNode: param.focusNode,
        textTheme: param.textTheme,
        onPressed: () {
          return (onPress != null) ? onPress(true) : null;
        },
        onLongPress: () {
          return (onLongPress != null) ? onLongPress(true) : null;
        },
        key: param.key,
      ),
    );
  }
}
